module.exports = function(grunt) {

	var assetsPath = 'src/*.js';

	grunt.initConfig({
		jshint: {
			all: ['GruntFile.js', assetsPath]
		},
		watch: {
			pivotal: {
				files: [assetsPath],
				tasks: ['jshint']
			}
		},
		concat: {
			zh: {
				options: {
					process: function(src, filepath) {
						return '\n' + '// FILE: ' + filepath + '\n' + src;
					}
				},
				src: [assetsPath],
				dest: 'dist/GridNavigationLibrary.js'
			}
		},
		uglify: {
			options: {
				mangle: false,
				compress: false,
				report: 'min',
				// the banner is inserted at the top of the output
				banner: '/*! <%= grunt.template.today("dd-mm-yyyy") %> */\n'
			},
			dist: {
				files: {
					'dist/GridNavigationLibrary.min.js': [assetsPath]
				}
			}
		},
		bump: {
			options: {
				files: ['bower.json', 'package.json'],
				pushTo: 'origin',
				commitFiles: ["-a"],
				push: true
			}
		},
		copy: {
			main: {
				expand: false,
				src: 'src/style.css',
				dest: 'dist/style.css'
			}
		},
		buildEnvironment: {
			development: {
				configFile: 'examples/config/development.json'
			},
			srcFolders: ['examples/frontend', 'examples/frontend/tests/functional']
		}
	});

	grunt.loadNpmTasks('grunt-contrib-jshint');
	grunt.loadNpmTasks('grunt-contrib-watch');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-bump');
	grunt.loadNpmTasks('grunt-contrib-copy');
	grunt.loadNpmTasks('grunt-zh-environment-builder');
	// Default task.
	grunt.registerTask('default', ['buildEnvironment', 'jshint', 'concat', 'uglify', 'copy']);

};